@@ -24,12 +24,12 @@
 ##
 ##  Set 'GAP_DIR' to the name of the directory where you have installed  GAP,
 ##  i.e., the directory with the subdirectories  'lib',  'grp',  'doc',  etc.
-##  The default is '/build/gap/src/gap-4.12.2',  which is the root directory if you install
+##  The default is '/build/gap/src/gap-4.14.0',  which is the root directory if you install
 ##  XGAP in the default `pkg' directory.
 ##  If you install XGAP in a private directory you have to change this.
 ##
 if [ "x$GAP_DIR" = "x" ];  then
-GAP_DIR="/build/gap/src/gap-4.12.2"
+GAP_DIR="/build/gap/src/gap-4.14.0"
 fi
 
 
@@ -38,13 +38,9 @@ fi
 ##  GAP_PRG . . . . . . . . . . . . . . . . .  name of the executable program
 ##
 ##  Set 'GAP_PRG' to the  name of the executable  program of the  GAP kernel.
-##  The  default is  '`hostname'/gap'.    You  can   either change this    to
-##  '<target>/gap' where <target> is the  target you have selected during the
-##  compilation or create  a symbolic link  from <target> to  '`hostname`' in
-##  the 'bin' directory.
 ##
 if [ "x$GAP_PRG" = "x" ];  then
-GAP_PRG=x86_64-pc-linux-gnu-default64-kv8/gap
+GAP_PRG=x86_64-pc-linux-gnu-default64-kv9/gap
 fi
 
 
@@ -53,13 +49,9 @@ fi
 ##  XGAP_PRG . . . . . . . . . . . . . . . . . name of the executable program
 ##
 ##  Set 'XGAP_PRG' to the  name of the executable program of the XGAP kernel.
-##  The  default is  '`hostname'/gap'.    You  can   either change this    to
-##  '<target>/gap' where <target> is the  target you have selected during the
-##  compilation or create  a symbolic link  from <target> to  '`hostname`' in
-##  the 'bin' directory.
 ##
 if [ "x$XGAP_PRG" = "x" ];  then
-XGAP_PRG=x86_64-pc-linux-gnu-gcc/xgap
+XGAP_PRG=x86_64-pc-linux-gnu-default64-kv9/xgap
 fi
 
 
@@ -101,7 +93,7 @@ VERBOSE="NO"
 ##
 ##  GAP accepts the following options:
 ##
-##  -b          toggle banner supression
+##  -b          toggle banner suppression
 ##  -q          toggle quiet mode
 ##  -e          toggle quitting on <ctr>-D
 ##  -f          force line editing
@@ -117,7 +109,7 @@ VERBOSE="NO"
 ##              postfix 'k' = *1024, 'm' = *1024*1024
 ##  -l <paths>  set the GAP root paths
 ##  -r          toggle reading of the '.gaprc' file 
-##  -D          toggle debuging the loading of library files
+##  -D          toggle debugging the loading of library files
 ##  -B <name>   current architecture
 ##  -M          toggle loading of compiled modules
 ##  -N          toggle check for completion files
@@ -228,7 +220,7 @@ fi;
 #############################################################################
 ##
 ##
-XGAP=/build/gap/src/gap-4.12.2/pkg/xgap/bin/$XGAP_PRG
+XGAP=/build/gap/src/gap-4.14.0/pkg/xgap/bin/$XGAP_PRG
 GAP=$GAP_DIR/bin/$GAP_PRG
 
 #############################################################################
